@@ -6,7 +6,7 @@ package Dist::Iller;
 
 # ABSTRACT: A Dist::Zilla & Pod::Weaver preprocessor
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1405';
+our $VERSION = '0.1406';
 
 use Dist::Iller::Elk;
 use Types::Standard qw/Map Str ConsumerOf/;
@@ -61,7 +61,7 @@ sub parse {
             module => __PACKAGE__,
             version => __PACKAGE__->VERSION,
             phase => 'develop',
-            relation => 'requires',
+            relation => 'suggests',
         ));
 
         DOC:
@@ -75,7 +75,7 @@ sub parse {
                     module => $included_config->[0],
                     version => $included_config->[1],
                     phase => 'develop',
-                    relation => 'requires',
+                    relation => 'suggests',
                 ));
             }
 
@@ -119,22 +119,21 @@ Dist::Iller - A Dist::Zilla & Pod::Weaver preprocessor
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-84.3%-orange.svg" alt="coverage 84.3%" /></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-0.1406"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller/0.1406" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Iller%200.1406"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller/0.1406" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-84.4%-orange.svg" alt="coverage 84.4%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.10+](https://img.shields.io/badge/perl-5.10+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller) ![coverage 84.3%](https://img.shields.io/badge/coverage-84.3%-orange.svg)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.1405, released 2016-02-15.
+Version 0.1406, released 2016-02-18.
 
 =head1 SYNOPSIS
 
