@@ -5,7 +5,7 @@ use warnings;
 package Dist::Iller::DocType::Dist;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1405';
+our $VERSION = '0.1406';
 
 use Dist::Iller::Elk;
 with qw/
@@ -164,6 +164,9 @@ sub add_plugins_as_prereqs {
     my @plugins = @_;
 
     for my $plugin (@plugins) {
+        if($plugin->has_prereqs) {
+            $self->add_prereq($_) for $plugin->all_prereqs;
+        }
         my $packages = $packages_for_plugin->($plugin);
 
         for my $package (@{ $packages }) {
@@ -249,7 +252,7 @@ Dist::Iller::DocType::Dist
 
 =head1 VERSION
 
-Version 0.1405, released 2016-02-15.
+Version 0.1406, released 2016-02-18.
 
 =head1 SOURCE
 
