@@ -5,12 +5,17 @@ use warnings;
 package Dist::Iller::Plugin;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1405';
+our $VERSION = '0.1406';
 
 use Dist::Iller::Elk;
 use Types::Standard qw/Str Enum HashRef/;
 use List::MoreUtils qw/uniq/;
 use MooseX::StrictConstructor;
+use Dist::Iller::Prereq;
+
+with qw/
+    Dist::Iller::Role::HasPrereqs
+/;
 
 has plugin_name => (
     is => 'ro',
@@ -49,6 +54,32 @@ has parameters => (
     },
 );
 
+around BUILDARGS => sub {
+    my $next = shift;
+    my $self = shift;
+    my $args = ref $_[0] eq 'HASH' ? shift : { @_ };
+
+    if(exists $args->{'prereqs'}) {
+        my $prereqs = [];
+
+        for my $prereq (@{ $args->{'prereqs'} }) {
+            my($phase, $relation) = split /_/ => (keys %{ $prereq })[0];
+            my($module, $version) = split / / => (values %{ $prereq })[0];
+            $version ||= 0;
+
+            push @{ $prereqs } => Dist::Iller::Prereq->new(
+                phase => $phase,
+                relation => $relation,
+                module => $module,
+                version => $version,
+            );
+        }
+        $args->{'prereqs'} = $prereqs;
+    }
+
+    $self->$next($args);
+};
+
 sub merge_with {
     my $self = shift;
     my $other_plugin = shift;
@@ -89,11 +120,11 @@ sub to_string {
 
         if(ref $value eq 'ARRAY') {
             foreach my $val (@$value) {
-                push @strings => sprintf '%s =%s%s', $parameter, defined $val ? ' ' : '', $val;
+                push @strings => sprintf '%s =%s%s', $parameter, defined $val ? ' ' : '', defined $val ? $val : '';
             }
         }
         else {
-            push @strings => sprintf '%s =%s%s', $parameter, defined $value ? ' ' : '', $value // '';
+            push @strings => sprintf '%s =%s%s', $parameter, defined $value ? ' ' : '', defined $value ? $value : '';
         }
     }
 
@@ -116,7 +147,7 @@ Dist::Iller::Plugin
 
 =head1 VERSION
 
-Version 0.1405, released 2016-02-15.
+Version 0.1406, released 2016-02-18.
 
 =head1 SOURCE
 
