@@ -5,7 +5,7 @@ use warnings;
 package Dist::Iller::Role::HasPlugins;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1405';
+our $VERSION = '0.1406';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -81,6 +81,7 @@ sub parse_plugin {
           maybe in => delete $plugin->{'+in'},
           maybe version => delete $plugin->{'+version'},
           maybe documentation => delete $plugin->{'+documentation'},
+          maybe prereqs => delete $plugin->{'+prereqs'},
                 parameters => $self->set_values_from_config($plugin),
     });
 }
@@ -328,6 +329,7 @@ sub plugins_to_hash {
                 provided $_->has_base, '+base' => $plugin->base,
                                        '+in' => $plugin->in,
                                        '+version' => $plugin->version,
+             provided $_->has_prereqs, '+prereqs' => $plugin->prereqs_to_array,
                                  maybe '+documentation' => $plugin->documentation,
                                        %{ $parameters },
             }
@@ -349,7 +351,7 @@ Dist::Iller::Role::HasPlugins
 
 =head1 VERSION
 
-Version 0.1405, released 2016-02-15.
+Version 0.1406, released 2016-02-18.
 
 =head1 SOURCE
 
