@@ -5,7 +5,7 @@ use warnings;
 package Dist::Iller::Role::HasPrereqs;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1405';
+our $VERSION = '0.1406';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -24,6 +24,7 @@ has prereqs => (
         find_prereq => 'first',
         get_prereq => 'get',
         all_prereqs => 'elements',
+        has_prereqs => 'count',
     },
 );
 
@@ -69,6 +70,18 @@ sub merge_prereqs {
     }
 }
 
+sub prereqs_to_array {
+    my $self = shift;
+
+    my $array = [];
+    for my $prereq ($self->all_prereqs) {
+        my $phase_relation = sprintf '%s_%s', $prereq->phase, $prereq->relation;
+        push @{ $array } => { $phase_relation => sprintf '%s %s', $prereq->module, $prereq->version };
+    }
+
+    return $array;
+}
+
 sub prereqs_to_hash {
     my $self = shift;
 
@@ -96,7 +109,7 @@ Dist::Iller::Role::HasPrereqs
 
 =head1 VERSION
 
-Version 0.1405, released 2016-02-15.
+Version 0.1406, released 2016-02-18.
 
 =head1 SOURCE
 
